@@ -10,6 +10,9 @@ class SourceTypes(str, Enum):
     thread = 'thread'
     comment = 'comment'
     community_summary = 'community_summary'
+    mobileapp_paid = 'mobileapp_paid'
+    mobileapp_in_progress = 'mobileapp_in_progress'
+    mobileapp_ready = 'mobileapp_ready'
 
 
 @dataclass
@@ -20,10 +23,15 @@ class Notification:
     portal_member_id: int
     title: str
     message: str = ''
+
     parent_id: Optional[int] = None
     parent_name: Optional[str] = None
+    parent_portal_member_id: Optional[int] = None
+
     notification_receivers: list[int] = field(default_factory=list)
+
     created_at: int = field(default_factory=get_current_timestamp_ms)
+    fcm_topic: Optional[str] = None
 
     args: Optional[dict[str, Any]] = None
     children: list["Notification"] = field(default_factory=list)
