@@ -54,19 +54,31 @@ class NotificationConnector(AsyncOnStart, AsyncOnStop):
             logger.error(f'write to kafka channel "{self._config.topic}" failed, error: {exc}')
             return False
 
-    async def mark_notification_as_read_internal(
-        self, user_id: int, source_type: SourceTypes, source_ids: list[int], timeout: int = 5
+    async def mark_notifications_as_read_internal(
+        self,
+        user_id: int,
+        source_type: SourceTypes,
+        source_ids: list[int],
+        server_name: str = 'unknown',
+        timeout: int = 5
     ) -> None:
-        logger.debug(f'mark notification for user({user_id}) as read for sources({source_type}): {source_ids}')
+        logger.debug(
+            f'mark notification for user({user_id}) as read for sources({source_type}): {source_ids}'
+        )
         async with self._http_client.post(
-            f'{self._config.url}/v1/mark_notification_as_read_internal',
+            f'{self._config.url}/v1/mark_notifications_as_read_internal',
             json={
                 'user_id': user_id,
                 'source_type': source_type,
                 'source_ids': source_ids,
             },
+            headers={
+                'server_name': server_name,
+            },
             timeout=timeout,
         ) as response:
-            logger.debug(f'mark notification as read done, status: {response.status}')
+            logger.debug(
+                f'mark notification as read done, status: {response.status} {response.reason}'
+            )
             response.raise_for_status()
             return await response.json()
